# Import core functions and essential elements (from other modules in the package)
from .auxiliary import *
from .utils import *
from .validation import *
from .visuals import *

# Optional: Any initialization code can go here (e.g., setting logging, initializing resources, etc.)
# import logging
# logging.basicConfig(
#   filename='valdata.log',
#   filemode='a',
#   level=logging.INFO,
#   format='%(asctime)s - %(levelname)s - %(message)s'
# )

# Metadata (optional)
__version__ = "0.0.1"
__author__ = "GabrielGod1"